/* $Id: nr_popup.js,v 1.1.2.1 2009/07/14 04:48:38 develCuy Exp $ */
Drupal.nr_popup = {
  /**
   * Collect values for quick access
   */
  OptionsCache: {},

  /**
   * Get container.
   */
  getContainer: function(fieldId) {
    return $('#' + fieldId).parents('div:first');
  },

  /**
   * Decorate and prepare given field(know by fieldId).
   */
  Attach: function(fieldId, fieldName, nodeType, nodeId) {
    field = Drupal.nr_popup.getContainer(fieldId);
    /* Move unselected to options cache*/
    Drupal.nr_popup.OptionsCache[fieldId] = [];
    $('#' + fieldId + ' option').each(function(i, option) {
      Drupal.nr_popup.OptionsCache[fieldId][$(option).val()*1] = $(option).text();
      if (!$(option).attr('selected')) {
        $('#' + fieldId).removeOption($(option).val());
      }
    });
    /* Insert button */
    field.append('<input type="button" value="' + Drupal.nr_popup.ButtonLabel.edit + '" id="' + fieldId + '_button" />');
    $('#' + fieldId + '_button').click(function() {
      Drupal.nr_popup.Show(field, fieldName, nodeType, nodeId, fieldId);
    });
  },

  /**
   * Prepare and show popup.
   */
  Show: function (field, fieldName, nodeType, nodeId, fieldId) {
    var _popup = $('#' + fieldId + '_popup');
    _popup.remove();
    field = Drupal.nr_popup.getContainer(fieldId);
    /* Insert popup with loader */
    field.append('<div id="' + fieldId + '_popup" class="flora"></div>');
    _popup = $('#' + fieldId + '_popup');
    _popup.hide();
    /* Show loader */
    _popup.html(Drupal.nr_popup.AjaxLoader);
    /* Prepare */
    var properties = {
      modal: true,
      overlay: {
        opacity: 0.5,
        background: 'black'
      },
      width: 550,
      minWidth: 350,
      height: 350,
      minHeight: 250,
      buttons: {}
    };
    properties.buttons[Drupal.nr_popup.ButtonLabel.close] = function() { $(this).dialog('close'); };
    _popup.dialog(properties);
    /* Display popup */
    _popup.show();
    var url = Drupal.settings.basePath + '?q=nr_popup_js/' + fieldName + '/' + nodeType + '/' + nodeId;
    Drupal.nr_popup.AjaxHandler(url, _popup, fieldId);
  },

  /**
   * Handle view ajax call on every load.
   */
  AjaxHandler: function (url, _popup, fieldId) {
    _popup.html(Drupal.nr_popup.AjaxLoader); /* show loader */
    $.get(url, function(data) {
      _popup.html(data);
      /* Header */
      $('.ui-dialog .view-cell-header a').click(function() {
        Drupal.nr_popup.AjaxHandler($(this).attr('href'), _popup);
        return false;
      });
      /* Row links */
      $('.ui-dialog .view-field a').click(function() {
        window.open($(this).attr("href"));
        return false;
      });
      /* Pager */
      $('.ui-dialog .pager a').click(function() {
        Drupal.nr_popup.AjaxHandler($(this).attr('href'), _popup, fieldId);
        return false;
      });
      $('.ui-dialog .view-content .view-field-node-nid').each(function(i, element) {
        if (i > 0) {
          var nodeId = $(element).text();
          // Attach Buttons
          $(element).html('<span></span><span></span>');
          /**
           * Attach add triggers to given object and decorates it.
           */
          $('span:even', element).click(function() {
            Drupal.nr_popup.AddNode(element, nodeId, fieldId);
          });
          add = !$('#' + fieldId).containsOption(nodeId);
          Drupal.nr_popup.switchToButton(element, 'add', add);
          /**
           * Attach remove triggers to given object and decorates it.
           */
          $('span:odd', element).click(function() {
            Drupal.nr_popup.RemNode(element, nodeId, fieldId);
          });
          Drupal.nr_popup.switchToButton(element, 'del', add);
        }
      });
    });
  },

  switchToButton: function(element, type, invert) {
    if (type == 'add') {
      $('span:even', element).attr({'class': '', 'style': ''});
    }
    else if (type == 'del') {
      $('span:odd', element).attr({'class': 'nr_popup-del', 'style': ''});
      invert = !invert;
    }
    if (invert) {
      $('span:even', element).hide();
      $('span:odd', element).show();
    }
    else {
      $('span:odd', element).hide();
      $('span:even', element).show();
    }
  },

  /**
   * Add new node reference node to select box.
   */
  AddNode: function (element, nodeId, fieldId) {
    Drupal.nr_popup.Throbbing('span:even', element);
    /* Add option */
    $('#' + fieldId).addOption(nodeId, Drupal.nr_popup.OptionsCache[fieldId][nodeId*1]);
    /* Remove throbber */
    Drupal.nr_popup.switchToButton(element, 'del', false);
  },

  /**
   * Remove referenced node from select box.
   */
  RemNode: function (element, nodeId, fieldId) {
    Drupal.nr_popup.Throbbing('span:odd', element);
    /* Remove option */
    $('#' + fieldId).removeOption(nodeId);
    /* Remove throbber */
    Drupal.nr_popup.switchToButton(element, 'add', false);
  },

  /**
   * Show throbber(ajax loader).
   */
  Throbbing: function(selector, element) {
    $(selector, element).attr({
      'class': 'nr_popup-throbbing',
      'style': 'background-image: url(' + Drupal.settings.basePath + 'misc/throbber.gif)'});
  }
};
